==> babel-build-1.0.1.tgz: package/lib/start.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _run = require('./run');

var _run2 = _interopRequireDefault(_run);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _clean = require('./clean');

var _clean2 = _interopRequireDefault(_clean);

var _copy = require('./copy');

var _copy2 = _interopRequireDefault(_copy);

var _webpack = require('webpack');

var _webpack2 = _interopRequireDefault(_webpack);

var _nodeServer = require('./nodeServer');

var _nodeServer2 = _interopRequireDefault(_nodeServer);

var _browserSync = require('browser-sync');

var _browserSync2 = _interopRequireDefault(_browserSync);

var _utils = require('./utils');

var _webpackMiddleware = require('webpack-middleware');

var _webpackMiddleware2 = _interopRequireDefault(_webpackMiddleware);

var _webpackHotMiddleware = require('webpack-hot-middleware');

var _webpackHotMiddleware2 = _interopRequireDefault(_webpackHotMiddleware);

var _webpackDevServer = require('./webpackDevServer');

var _webpackDevServer2 = _interopRequireDefault(_webpackDevServer);

var _webpack3 = require('./webpack.config');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * Created by Zhengfeng.Yao on 16/9/22.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            */


module.exports = function () {
  var _ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee2(options) {
    var _this = this;

    var webpackConfig, dirs, aegisConfig, node, server;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            webpackConfig = (0, _webpack3.getWebpackConfig)(options);

            if (!options.clean) {
              _context2.next = 5;
              break;
            }

            dirs = webpackConfig.map(function (config) {
              return config.output.path;
            });
            _context2.next = 5;
            return (0, _run2.default)(_clean2.default.bind(undefined, dirs));

          case 5:
            aegisConfig = (0, _utils.loadAegisConfig)(options.dev ? '.dev' : '');

            if (!aegisConfig.copy) {
              _context2.next = 9;
              break;
            }

            _context2.next = 9;
            return (0, _run2.default)(_copy2.default.bind(undefined, aegisConfig.copy, true));

          case 9:
            node = options.node;

            if (node) {
              _context2.next = 14;
              break;
            }

            server = new _webpackDevServer2.default(options);
            _context2.next = 14;
            return server.run();

          case 14:
            if (!node) {
              _context2.next = 16;
              break;
            }

            return _context2.delegateYield(regeneratorRuntime.mark(function _callee() {
              var runServer;
              return regeneratorRuntime.wrap(function _callee$(_context) {
                while (1) {
                  switch (_context.prev = _context.next) {
                    case 0:
                      runServer = (0, _nodeServer2.default)(options);
                      _context.next = 3;
                      return new Promise(function (resolve) {
                        webpackConfig.filter(function (x) {
                          return x.target !== 'node';
                        }).forEach(function (config) {
                          if (Array.isArray(config.entry)) {
                            config.entry.unshift('webpack-hot-middleware/client');
                          } else if (config.entry.constructor == Object) {
                            Object.keys(config.entry).forEach(function (key) {
                              if (Array.isArray(config.entry[key])) {
                                config.entry[key].unshift('webpack-hot-middleware/client');
                              } else {
                                config.entry[key] = ['webpack-hot-middleware/client', config.entry[key]];
                              }
                            });
                          } else {
                            config.entry = ['webpack-hot-middleware/client', config.entry];
                          }

                          config.plugins.push(new _webpack2.default.HotModuleReplacementPlugin());
                          config.plugins.push(new _webpack2.default.NoErrorsPlugin());
                          config.module.loaders.filter(function (x) {
                            return x.loader.indexOf('babel') !== -1;
                          }).forEach(function (x) {
                            return x.query = {
                              plugins: [].concat(_toConsumableArray(config.babel.plugins), [[require.resolve('babel-plugin-react-transform'), {
                                transforms: [{
                                  transform: 'react-transform-hmr',
                                  imports: ['react'],
                                  locals: ['module']
                                }, {
                                  transform: 'react-transform-catch-errors',
                                  imports: ['react', 'redbox-react']
                                }]
                              }]])
                            };
                          });
                        });

                        var bundler = (0, _webpack2.default)(webpackConfig);
                        var wpMiddleware = (0, _webpackMiddleware2.default)(bundler, {

                          // IMPORTANT: webpack middleware can't access config,
                          // so we should provide publicPath by ourselves
                          publicPath: '/',

                          // Pretty colored output
                          stats: webpackConfig[0].stats

                        });
                        var hotMiddlewares = bundler.compilers.filter(function (compiler) {
                          return compiler.options.target !== 'node';
                        }).map(function (compiler) {
                          return (0, _webpackHotMiddleware2.default)(compiler);
                        });

                        var files = [];
                        if (aegisConfig.copy) {
                          if (Array.isArray(aegisConfig.copy)) {
                            files = aegisConfig.copy.map(function (source) {
                              return _path2.default.join(source, '**/*.*');
                            });
                          } else {
                            files.push(_path2.default.join(aegisConfig.copy.source, '**/*.*'));
                          }
                        }

                        var _handleServerBundleComplete = function handleServerBundleComplete() {
                          runServer(function (err, host) {
                            if (!err) {
                              var bs = _browserSync2.default.create();
                              bs.init(_extends({}, options.dev ? {} : { notify: false, ui: false }, {

                                proxy: {
                                  target: host,
                                  middleware: [wpMiddleware].concat(_toConsumableArray(hotMiddlewares))
                                },

                                files: files
                              }), resolve);
                              _handleServerBundleComplete = runServer;
                            }
                          });
                        };

                        bundler.plugin('done', function () {
                          return _handleServerBundleComplete();
                        });
                      });

                    case 3:
                    case 'end':
                      return _context.stop();
                  }
                }
              }, _callee, _this);
            })(), 't0', 16);

          case 16:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this);
  }));

  function start(_x) {
    return _ref.apply(this, arguments);
  }

  return start;
}();

==> babel-build-1.0.2.tgz: package/lib/start.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _run = require('./run');

var _run2 = _interopRequireDefault(_run);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _clean = require('./clean');

var _clean2 = _interopRequireDefault(_clean);

var _copy = require('./copy');

var _copy2 = _interopRequireDefault(_copy);

var _webpack = require('webpack');

var _webpack2 = _interopRequireDefault(_webpack);

var _nodeServer = require('./nodeServer');

var _nodeServer2 = _interopRequireDefault(_nodeServer);

var _browserSync = require('browser-sync');

var _browserSync2 = _interopRequireDefault(_browserSync);

var _utils = require('./utils');

var _webpackMiddleware = require('webpack-middleware');

var _webpackMiddleware2 = _interopRequireDefault(_webpackMiddleware);

var _webpackHotMiddleware = require('webpack-hot-middleware');

var _webpackHotMiddleware2 = _interopRequireDefault(_webpackHotMiddleware);

var _webpackDevServer = require('./webpackDevServer');

var _webpackDevServer2 = _interopRequireDefault(_webpackDevServer);

var _webpack3 = require('./webpack.config');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * Created by Zhengfeng.Yao on 16/9/22.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            */


module.exports = function () {
  var _ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee2(options) {
    var _this = this;

    var webpackConfig, dirs, aegisConfig, node, server;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            webpackConfig = (0, _webpack3.getWebpackConfig)(options);

            if (!options.clean) {
              _context2.next = 5;
              break;
            }

            dirs = webpackConfig.map(function (config) {
              return config.output.path;
            });
            _context2.next = 5;
            return (0, _run2.default)(_clean2.default.bind(undefined, dirs, options.force));

          case 5:
            aegisConfig = (0, _utils.loadAegisConfig)(options.dev ? '.dev' : '');

            if (!aegisConfig.copy) {
              _context2.next = 9;
              break;
            }

            _context2.next = 9;
            return (0, _run2.default)(_copy2.default.bind(undefined, aegisConfig.copy, true));

          case 9:
            node = options.node;

            if (node) {
              _context2.next = 14;
              break;
            }

            server = new _webpackDevServer2.default(options);
            _context2.next = 14;
            return server.run();

          case 14:
            if (!node) {
              _context2.next = 16;
              break;
            }

            return _context2.delegateYield(regeneratorRuntime.mark(function _callee() {
              var runServer;
              return regeneratorRuntime.wrap(function _callee$(_context) {
                while (1) {
                  switch (_context.prev = _context.next) {
                    case 0:
                      runServer = (0, _nodeServer2.default)(options);
                      _context.next = 3;
                      return new Promise(function (resolve) {
                        webpackConfig.filter(function (x) {
                          return x.target !== 'node';
                        }).forEach(function (config) {
                          if (Array.isArray(config.entry)) {
                            config.entry.unshift('webpack-hot-middleware/client');
                          } else if (config.entry.constructor == Object) {
                            Object.keys(config.entry).forEach(function (key) {
                              if (Array.isArray(config.entry[key])) {
                                config.entry[key].unshift('webpack-hot-middleware/client');
                              } else {
                                config.entry[key] = ['webpack-hot-middleware/client', config.entry[key]];
                              }
                            });
                          } else {
                            config.entry = ['webpack-hot-middleware/client', config.entry];
                          }

                          config.plugins.push(new _webpack2.default.HotModuleReplacementPlugin());
                          config.plugins.push(new _webpack2.default.NoErrorsPlugin());
                          config.module.loaders.filter(function (x) {
                            return x.loader.indexOf('babel') !== -1;
                          }).forEach(function (x) {
                            return x.query = {
                              plugins: [].concat(_toConsumableArray(config.babel.plugins), [[require.resolve('babel-plugin-react-transform'), {
                                transforms: [{
                                  transform: 'react-transform-hmr',
                                  imports: ['react'],
                                  locals: ['module']
                                }, {
                                  transform: 'react-transform-catch-errors',
                                  imports: ['react', 'redbox-react']
                                }]
                              }]])
                            };
                          });
                        });

                        var bundler = (0, _webpack2.default)(webpackConfig);
                        var wpMiddleware = (0, _webpackMiddleware2.default)(bundler, {

                          // IMPORTANT: webpack middleware can't access config,
                          // so we should provide publicPath by ourselves
                          publicPath: '/',

                          // Pretty colored output
                          stats: webpackConfig[0].stats

                        });
                        var hotMiddlewares = bundler.compilers.filter(function (compiler) {
                          return compiler.options.target !== 'node';
                        }).map(function (compiler) {
                          return (0, _webpackHotMiddleware2.default)(compiler);
                        });

                        var files = [];
                        if (aegisConfig.copy) {
                          if (Array.isArray(aegisConfig.copy)) {
                            files = aegisConfig.copy.map(function (source) {
                              return _path2.default.join(source, '**/*.*');
                            });
                          } else {
                            files.push(_path2.default.join(aegisConfig.copy.source, '**/*.*'));
                          }
                        }

                        var _handleServerBundleComplete = function handleServerBundleComplete() {
                          runServer(function (err, host) {
                            if (!err) {
                              var bs = _browserSync2.default.create();
                              bs.init(_extends({}, options.dev ? {} : { notify: false, ui: false }, {

                                proxy: {
                                  target: host,
                                  middleware: [wpMiddleware].concat(_toConsumableArray(hotMiddlewares))
                                },

                                files: files
                              }), resolve);
                              _handleServerBundleComplete = runServer;
                            }
                          });
                        };

                        bundler.plugin('done', function () {
                          return _handleServerBundleComplete();
                        });
                      });

                    case 3:
                    case 'end':
                      return _context.stop();
                  }
                }
              }, _callee, _this);
            })(), 't0', 16);

          case 16:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this);
  }));

  function start(_x) {
    return _ref.apply(this, arguments);
  }

  return start;
}();
